@@ -423,7 +423,7 @@ static void assigning(bdz_config_data_t *bdz, bdz_graph3_t* graph3, bdz_queue_t
 	memset(marked_vertices, 0, (size_t)(bdz->n >> 3) + 1);
 	memset(bdz->g, 0xff, (size_t)(sizeg));
 
-	for(i=nedges-1;i+1>=1;i--){
+	for(i=nedges-1;i+1>0;i--){
 		curr_edge=queue[i];
 		v0=graph3->edges[curr_edge].vertices[0];
 		v1=graph3->edges[curr_edge].vertices[1];
@@ -455,14 +455,6 @@ static void assigning(bdz_config_data_t *bdz, bdz_graph3_t* graph3, bdz_queue_t
 			SETBIT(marked_vertices, v2);
 		}		
 		DEBUGP("A:%u %u %u -- %u %u %u\n", v0, v1, v2, GETVALUE(bdz->g, v0), GETVALUE(bdz->g, v1), GETVALUE(bdz->g, v2));
-
-#if (_MSC_VER > 1699 && _MSC_VER < 1800)
-		/* This is bad, MSVC 2012 X64 getting confused with the value of i... */
-		/* an obvious MSVC 2012 X64 compiler bug :| */
-		if (i <= 0)
-			break;
-#endif
-
 	};
 	free(marked_vertices);
 }
