@@ -144,7 +144,7 @@ class GDumpParser(object):
         """Load the library (or executable), returning an XML
 blob containing data gleaned from GObject's primitive introspection."""
         in_path = os.path.join(self._binary.tmpdir, 'functions.txt')
-        with open(in_path, 'w') as f:
+        with open(in_path, 'w', encoding='utf-8') as f:
             for func in self._get_type_functions:
                 f.write('get-type:')
                 f.write(func)
@@ -262,10 +262,12 @@ blob containing data gleaned from GObject's primitive introspection."""
         # values as a 32-bit signed integer, even if they were unsigned
         # in the source code.
         previous_values = {}
+        previous_symbols = {}
         previous = self._namespace.get(enum_name)
         if isinstance(previous, (ast.Enum, ast.Bitfield)):
             for member in previous.members:
                 previous_values[member.name] = member.value
+                previous_symbols[member.name] = member.symbol
 
         members = []
         for member in xmlnode.findall('member'):
@@ -275,13 +277,16 @@ blob containing data gleaned from GObject's primitive introspection."""
 
             if name in previous_values:
                 value = previous_values[name]
+                symbol = previous_symbols[name]
             else:
                 value = member.attrib['value']
+                symbol = member.attrib['name']
 
             members.append(ast.Member(name,
                                       value,
-                                      member.attrib['name'],
-                                      member.attrib['nick']))
+                                      symbol,
+                                      member.attrib['nick'],
+                                      member.attrib['name']))
 
         if xmlnode.tag == 'flags':
             klass = ast.Bitfield
@@ -315,6 +320,7 @@ different --identifier-prefix.""" % (xmlnode.attrib['name'], self._namespace.ide
     def _introspect_object(self, xmlnode):
         type_name = xmlnode.attrib['name']
         is_abstract = bool(xmlnode.attrib.get('abstract', False))
+        is_final = bool(xmlnode.attrib.get('final', False))
         (get_type, c_symbol_prefix) = self._split_type_and_symbol_prefix(xmlnode)
         try:
             object_name = self._transformer.strip_identifier(type_name)
@@ -324,7 +330,8 @@ different --identifier-prefix.""" % (xmlnode.attrib['name'], self._namespace.ide
                          gtype_name=type_name,
                          get_type=get_type,
                          c_symbol_prefix=c_symbol_prefix,
-                         is_abstract=is_abstract)
+                         is_abstract=is_abstract,
+                         is_final=is_final)
         self._parse_parents(xmlnode, node)
         self._introspect_properties(node, xmlnode)
         self._introspect_signals(node, xmlnode)
@@ -453,6 +460,7 @@ different --identifier-prefix.""" % (xmlnode.attrib['name'], self._namespace.ide
         type_name = xmlnode.attrib['name']
 
         is_abstract = bool(xmlnode.attrib.get('abstract', False))
+        is_final = bool(xmlnode.attrib.get('final', False))
         (get_type, c_symbol_prefix) = self._split_type_and_symbol_prefix(xmlnode)
         try:
             fundamental_name = self._transformer.strip_identifier(type_name)
@@ -464,7 +472,8 @@ different --identifier-prefix.""" % (xmlnode.attrib['name'], self._namespace.ide
                          gtype_name=type_name,
                          get_type=get_type,
                          c_symbol_prefix=c_symbol_prefix,
-                         is_abstract=is_abstract)
+                         is_abstract=is_abstract,
+                         is_final=is_final)
         self._parse_parents(xmlnode, node)
         node.fundamental = True
         self._introspect_implemented_interfaces(node, xmlnode)
