@@ -827,6 +827,12 @@ RegressTestObj*   regress_test_obj_new_from_file (const char *x, GError **error)
 _GI_TEST_EXTERN
 void       regress_test_obj_set_bare (RegressTestObj *obj, GObject *bare);
 
+_GI_TEST_EXTERN
+void       regress_test_obj_set_string (RegressTestObj *obj, const char *str);
+
+_GI_TEST_EXTERN
+const char *regress_test_obj_get_string (RegressTestObj *obj);
+
 _GI_TEST_EXTERN
 void       regress_test_obj_emit_sig_with_obj (RegressTestObj *obj);
 
@@ -868,12 +874,12 @@ _GI_TEST_EXTERN
 void regress_test_array_fixed_out_objects (RegressTestObj ***objs);
 
 #if (defined(__GNUC__) || defined(__clang__)) && defined(__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
-_GI_TEST_EXTERN
-void regress_test_array_static_in_int (int x[static 10]);
+# define G_GCC_STATIC static
 #else
-_GI_TEST_EXTERN
-void regress_test_array_static_in_int (int x[10]);
+# define G_GCC_STATIC
 #endif
+_GI_TEST_EXTERN
+void regress_test_array_static_in_int (int x[G_GCC_STATIC 10]);
 
 _GI_TEST_EXTERN
 void regress_test_obj_torture_signature_0 (RegressTestObj    *obj,
@@ -1073,6 +1079,40 @@ struct _RegressTestFundamentalSubObjectClass {
 _GI_TEST_EXTERN
 GType regress_test_fundamental_sub_object_get_type(void);
 
+struct _RegressTestFundamentalObjectNoGetSetFunc {
+  /* This is not really an RegressTestFundamentalObject but we "inherit"
+   * the structure from it */
+  /* < private > */
+  RegressTestFundamentalObject fundamental_object;
+
+  /* < public > */
+  char *data;
+};
+
+struct _RegressTestFundamentalObjectNoGetSetFuncClass {
+  RegressTestFundamentalObjectClass fundamental_object_class;
+};
+
+typedef struct _RegressTestFundamentalObjectNoGetSetFunc RegressTestFundamentalObjectNoGetSetFunc;
+typedef struct _RegressTestFundamentalObjectNoGetSetFuncClass RegressTestFundamentalObjectNoGetSetFuncClass;
+
+_GI_TEST_EXTERN
+GType regress_test_fundamental_object_no_get_set_func_get_type (void);
+
+struct _RegressTestFundamentalSubObjectNoGetSetFunc {
+  /* < private > */
+  RegressTestFundamentalObjectNoGetSetFunc fundamental_object;
+};
+
+struct _RegressTestFundamentalSubObjectNoGetSetFuncClass {
+  RegressTestFundamentalObjectNoGetSetFuncClass fundamental_object_class;
+};
+
+typedef struct _RegressTestFundamentalSubObjectNoGetSetFunc RegressTestFundamentalSubObjectNoGetSetFunc;
+typedef struct _RegressTestFundamentalSubObjectNoGetSetFuncClass RegressTestFundamentalSubObjectNoGetSetFuncClass;
+
+_GI_TEST_EXTERN
+GType regress_test_fundamental_sub_object_no_get_set_func_get_type (void);
 
 _GI_TEST_EXTERN
 RegressTestFundamentalSubObject *
@@ -1082,6 +1122,22 @@ _GI_TEST_EXTERN
 RegressTestFundamentalObject *
 regress_test_create_fundamental_hidden_class_instance (void);
 
+_GI_TEST_EXTERN
+RegressTestFundamentalObjectNoGetSetFunc *
+regress_test_fundamental_object_no_get_set_func_new (const char *data);
+
+_GI_TEST_EXTERN
+const char *
+regress_test_fundamental_object_no_get_set_func_get_data (RegressTestFundamentalObjectNoGetSetFunc *fundamental);
+
+_GI_TEST_EXTERN
+RegressTestFundamentalSubObjectNoGetSetFunc *
+regress_test_fundamental_sub_object_no_get_set_func_new (const char *data);
+
+_GI_TEST_EXTERN
+void
+regress_test_fundamental_object_no_get_set_func_make_compatible_with_fundamental_sub_object (void);
+
 /* callback */
 typedef void (*RegressTestSimpleCallback) (void);
 typedef void RegressTestNoPtrCallback (void);
